import type { genericValidation } from "#types/lib";

const nameRestrictions: genericValidation = {
	length: { min: 3, max: 20 },
	regex: /^[\p{L}\p{N}._-]+$/u,
};

const reservedNames = [
	"admin",
	"root",
	"system",
	"administrator",
	"mod",
	"moderator",
	"owner",
	"superuser",
	"sudo",
	"staff",
	"support",
	"help",

	"server",
	"guild",
	"channel",

	"null",
	"undefined",
	"void",
	"nil",
	"none",
	"empty",
	"blank",
	"true",
	"false",
	"yes",
	"no",
	"on",
	"off",

	"official",
	"verified",
	"team",
	"company",
	"corp",
	"inc",
	"llc",
	"trademark",
	"copyright",
	"dmca",

	"online",
	"offline",
	"away",
	"busy",
	"dnd",
	"invisible",
	"active",
	"inactive",
	"banned",
	"suspended",
	"deleted",
];

const displayNameRestrictions: genericValidation = {
	length: { min: 1, max: 32 },
	regex: /^[\p{L}\p{N}\p{M}\p{S}\p{P}\s]+$/u,
};

const forbiddenDisplayNamePatterns = [
	/[\r\n\t]/,
	/\s{3,}/,
	/^\s|\s$/,
	/\p{Cf}/u,
	/\p{Cc}/u,
];

const passwordRestrictions: genericValidation = {
	length: { min: 12, max: 64 },
	regex: /^(?=.*\p{Ll})(?=.*\p{Lu})(?=.*\d)(?=.*[^\w\s]).{12,64}$/u,
};

const emailRestrictions: { regex: RegExp } = {
	regex: /^[^\s@]+@[^\s@]+\.[^\s@]+$/,
};

const avatarRestrictions: genericValidation = {
	length: { min: 1, max: 5 * 1024 * 1024 }, // 5 MB
	regex: /^(data:image\/(jpeg|png|gif|webp);base64,)/,
};

export {
	nameRestrictions,
	displayNameRestrictions,
	forbiddenDisplayNamePatterns,
	passwordRestrictions,
	emailRestrictions,
	reservedNames,
	avatarRestrictions,
};
