import type { MailerConfig } from "#types/config";

function createMailerConfig(): MailerConfig {
	const smtpAddress = process.env.SMTP_ADDRESS || "";
	const smtpPort = process.env.SMTP_PORT || "587";
	const smtpFrom = process.env.SMTP_FROM || "";
	const smtpUsername = process.env.SMTP_USERNAME || "";
	const smtpPassword = process.env.SMTP_PASSWORD || "";
	const smtpSecure = process.env.SMTP_SECURE || "false";
	const smtpPool = process.env.SMTP_POOL || "true";

	const configForValidation: MailerConfig = {
		address: smtpAddress,
		port: Number.parseInt(smtpPort, 10),
		from: smtpFrom,
		username: smtpUsername,
		password: smtpPassword,
		secure: smtpSecure === "true",
		pool: smtpPool === "true",
		connectionTimeout: Number.parseInt(
			process.env.SMTP_CONNECTION_TIMEOUT || "30000",
			10,
		),
		socketTimeout: Number.parseInt(
			process.env.SMTP_SOCKET_TIMEOUT || "30000",
			10,
		),
		maxConnections: Number.parseInt(
			process.env.SMTP_MAX_CONNECTIONS || "5",
			10,
		),
		maxMessages: Number.parseInt(process.env.SMTP_MAX_MESSAGES || "100", 10),
		replyTo: process.env.SMTP_REPLY_TO || smtpFrom,
	};

	return configForValidation;
}

export const mailerConfig = createMailerConfig();
