import { Echo, echo } from "@atums/echo";
import { handleCommands } from "#commands";

import { verifyRequiredVariables } from "#environment/config";
import { migrationRunner } from "#lib/database";
import { mailerService } from "#lib/mailer";
import { serverHandler } from "#server";

const noFileLog = new Echo({
	disableFile: true,
});

async function main(): Promise<void> {
	const commandHandled = await handleCommands();
	if (commandHandled) process.exit(0);

	verifyRequiredVariables();

	await migrationRunner.initialize();
	await mailerService.verifyConnection();

	serverHandler.initialize();
}

main().catch((error: Error) => {
	echo.error({ message: "Error initializing the server:", error });
	process.exit(1);
});

export { noFileLog };
