function getExpirationInSeconds(expiration: string): number {
	const match = expiration.match(/^(\d+)([smhdwy])$/);
	if (!match) throw new Error("Invalid expiresIn format in jwt config");

	const [, value, unit] = match;
	const num = Number(value);

	switch (unit) {
		case "s":
			return num;
		case "m":
			return num * 60;
		case "h":
			return num * 3600;
		case "d":
			return num * 86400;
		case "w":
			return num * 604800; // 7 days
		case "y":
			return num * 31536000; // 365 days
		default:
			throw new Error("Invalid time unit in expiresIn");
	}
}

function formatSecondsToTimeString(seconds: number): string {
	if (seconds < 60) return `${seconds}s`;
	if (seconds < 3600) return `${Math.floor(seconds / 60)}m`;
	if (seconds < 86400) return `${Math.floor(seconds / 3600)}h`;
	if (seconds < 604800) return `${Math.floor(seconds / 86400)}d`;
	if (seconds < 31536000) return `${Math.floor(seconds / 604800)}w`;
	return `${Math.floor(seconds / 31536000)}y`;
}

export { getExpirationInSeconds, formatSecondsToTimeString };
