import { passwordRestrictions } from "#environment/constants";
import type { validationResult } from "#types/lib";

function isValidPassword(rawPassword: string): validationResult {
	if (typeof rawPassword !== "string") {
		return { valid: false, error: "Password must be a string" };
	}

	if (!rawPassword) {
		return { valid: false, error: "Password is required" };
	}

	if (rawPassword.length < passwordRestrictions.length.min) {
		return {
			valid: false,
			error: `Password must be at least ${passwordRestrictions.length.min} characters`,
		};
	}

	if (rawPassword.length > passwordRestrictions.length.max) {
		return {
			valid: false,
			error: `Password must be at most ${passwordRestrictions.length.max} characters`,
		};
	}

	if (!passwordRestrictions.regex.test(rawPassword)) {
		return {
			valid: false,
			error:
				"Password must contain at least one uppercase, one lowercase, one digit, and one special character",
		};
	}

	return { valid: true };
}

export { passwordRestrictions, isValidPassword };
